@@ -7,14 +7,15 @@ PRE_COMMIT {
     # CONFIG: Uncomment the following return to disable all checks
     # return;
 
-    use autodie;
+    use autodie qw(:all);
+    use Cwd;
     use File::Temp;
     use IO::Handle;
 
     my @javas = grep {/\.java$/} ($svnlook->added(), $svnlook->updated());
     return unless @javas;
 
-    # CONFIG: Set $limit to 0 to have no limits
+    # CONFIG: Set $limit to 0 to have no limits on the number of files to be checked.
     if (my $limit = 10) {
 	splice @javas, $limit if @javas > $limit;
     }
@@ -27,9 +28,13 @@ PRE_COMMIT {
 	$fh->print($svnlook->cat($java));
     }
 
+    my $cwd = cwd();
+    chdir '/ha/subversion/admin/hooks/dsb';
+
     # Invoke the code quality tool on all saved java files
-    system('java', '-jar', 'code-quality-hook-1.0-SNAPSHOT.jar', glob("$dir/*.java")) == 0
-	or die;
+    system('java', '-jar', 'code-quality-hook-1.0-SNAPSHOT.jar', glob("$dir/*.java"));
+
+    chdir $cwd;
 };
 
 1;
